#[non_exhaustive]pub struct GenerateAuthRequestCryptogramOutput {
pub key_arn: String,
pub key_check_value: String,
pub auth_request_cryptogram: String,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key_arn: StringThe keyARN of the IMK-AC that Amazon Web Services Payment Cryptography uses for ARQC generation.
key_check_value: StringThe key check value (KCV) of the encryption key. The KCV is used to check if all parties holding a given key have the same key or to detect that a key has changed.
Amazon Web Services Payment Cryptography computes the KCV according to the CMAC specification.
auth_request_cryptogram: StringThe Authorization Request Cryptogram (ARQC) generated by Amazon Web Services Payment Cryptography using the specified key and transaction data.
Implementations
Sourceimpl GenerateAuthRequestCryptogramOutput
impl GenerateAuthRequestCryptogramOutput
Sourcepub fn key_arn(&self) -> &str
pub fn key_arn(&self) -> &str
The keyARN of the IMK-AC that Amazon Web Services Payment Cryptography uses for ARQC generation.
Sourcepub fn key_check_value(&self) -> &str
pub fn key_check_value(&self) -> &str
The key check value (KCV) of the encryption key. The KCV is used to check if all parties holding a given key have the same key or to detect that a key has changed.
Amazon Web Services Payment Cryptography computes the KCV according to the CMAC specification.
Sourcepub fn auth_request_cryptogram(&self) -> &str
pub fn auth_request_cryptogram(&self) -> &str
The Authorization Request Cryptogram (ARQC) generated by Amazon Web Services Payment Cryptography using the specified key and transaction data.
Sourceimpl GenerateAuthRequestCryptogramOutput
impl GenerateAuthRequestCryptogramOutput
Sourcepub fn builder() -> GenerateAuthRequestCryptogramOutputBuilder
pub fn builder() -> GenerateAuthRequestCryptogramOutputBuilder
Creates a new builder-style object to manufacture GenerateAuthRequestCryptogramOutput.