#[non_exhaustive]pub struct KekValidationResponseBuilder { /* private fields */ }Expand description
A builder for KekValidationResponse.
Implementations
Sourceimpl KekValidationResponseBuilder
impl KekValidationResponseBuilder
Sourcepub fn random_key_send(self, input: impl Into<String>) -> Self
pub fn random_key_send(self, input: impl Into<String>) -> Self
The random key send value received from the initiating node to generate a KEK validation response.
This field is required.Sourcepub fn set_random_key_send(self, input: Option<String>) -> Self
pub fn set_random_key_send(self, input: Option<String>) -> Self
The random key send value received from the initiating node to generate a KEK validation response.
Sourcepub fn get_random_key_send(&self) -> &Option<String>
pub fn get_random_key_send(&self) -> &Option<String>
The random key send value received from the initiating node to generate a KEK validation response.
Sourcepub fn build(self) -> Result<KekValidationResponse, BuildError>
pub fn build(self) -> Result<KekValidationResponse, BuildError>
Consumes the builder and constructs a KekValidationResponse.
This method will fail if any of the following fields are not set: