#[non_exhaustive]pub struct SessionKeyUnionPayBuilder { /* private fields */ }Expand description
A builder for SessionKeyUnionPay.
Implementations
Sourceimpl SessionKeyUnionPayBuilder
impl SessionKeyUnionPayBuilder
Sourcepub fn primary_account_number(self, input: impl Into<String>) -> Self
pub fn primary_account_number(self, input: impl Into<String>) -> Self
The Primary Account Number (PAN) of the cardholder. A PAN is a unique identifier for a payment credit or debit card and associates the card to a specific account holder.
This field is required.Sourcepub fn set_primary_account_number(self, input: Option<String>) -> Self
pub fn set_primary_account_number(self, input: Option<String>) -> Self
The Primary Account Number (PAN) of the cardholder. A PAN is a unique identifier for a payment credit or debit card and associates the card to a specific account holder.
Sourcepub fn get_primary_account_number(&self) -> &Option<String>
pub fn get_primary_account_number(&self) -> &Option<String>
The Primary Account Number (PAN) of the cardholder. A PAN is a unique identifier for a payment credit or debit card and associates the card to a specific account holder.
Sourcepub fn pan_sequence_number(self, input: impl Into<String>) -> Self
pub fn pan_sequence_number(self, input: impl Into<String>) -> Self
A number that identifies and differentiates payment cards with the same Primary Account Number (PAN). If not used, enter 00.
Sourcepub fn set_pan_sequence_number(self, input: Option<String>) -> Self
pub fn set_pan_sequence_number(self, input: Option<String>) -> Self
A number that identifies and differentiates payment cards with the same Primary Account Number (PAN). If not used, enter 00.
Sourcepub fn get_pan_sequence_number(&self) -> &Option<String>
pub fn get_pan_sequence_number(&self) -> &Option<String>
A number that identifies and differentiates payment cards with the same Primary Account Number (PAN). If not used, enter 00.
Sourcepub fn application_transaction_counter(self, input: impl Into<String>) -> Self
pub fn application_transaction_counter(self, input: impl Into<String>) -> Self
The transaction counter that the terminal provides during transaction processing. This value is in hexadecimal format. For example, enter a decimal counter of 109 as 006D.
Sourcepub fn set_application_transaction_counter(self, input: Option<String>) -> Self
pub fn set_application_transaction_counter(self, input: Option<String>) -> Self
The transaction counter that the terminal provides during transaction processing. This value is in hexadecimal format. For example, enter a decimal counter of 109 as 006D.
Sourcepub fn get_application_transaction_counter(&self) -> &Option<String>
pub fn get_application_transaction_counter(&self) -> &Option<String>
The transaction counter that the terminal provides during transaction processing. This value is in hexadecimal format. For example, enter a decimal counter of 109 as 006D.
Sourcepub fn build(self) -> Result<SessionKeyUnionPay, BuildError>
pub fn build(self) -> Result<SessionKeyUnionPay, BuildError>
Consumes the builder and constructs a SessionKeyUnionPay.
This method will fail if any of the following fields are not set: