GenerateAuthRequestCryptogramFluentBuilder

Struct GenerateAuthRequestCryptogramFluentBuilder 

pub struct GenerateAuthRequestCryptogramFluentBuilder { /* private fields */ }
Fluent builder constructing a request to GenerateAuthRequestCryptogram.

Generates an Authorization Request Cryptogram (ARQC) for an EMV chip payment card authorization. For more information, see Generate auth request cryptogram in the Amazon Web Services Payment Cryptography User Guide.

ARQC generation uses an Issuer Master Key (IMK) for application cryptograms (TR31_E0_EMV_MKEY_APP_CRYPTOGRAMS) to derive a session key, which is then used to generate the cryptogram from the provided transaction data (when applicable). To use this operation, you must first create or import an IMK-AC key by calling CreateKey or ImportKey. The KeyModesOfUse should be set to DeriveKey for the IMK-AC encryption key.

This operation is intended for development and testing scenarios only. It is not recommended to use this operation as a substitute for card-based cryptogram generation in production payment flows.

For information about valid keys for this operation, see Understanding key attributes and Key types for specific data operations in the Amazon Web Services Payment Cryptography User Guide.

Cross-account use: This operation supports cross-account use when the key has a resource-based policy that grants access. For more information, see Resource-based policies.

Related operations:

  • VerifyAuthRequestCryptogram

Implementations

Source

impl GenerateAuthRequestCryptogramFluentBuilder

pub fn as_input(&self) -> &GenerateAuthRequestCryptogramInputBuilder

Access the GenerateAuthRequestCryptogram as a reference.

pub async fn send( self, ) -> Result<GenerateAuthRequestCryptogramOutput, SdkError<GenerateAuthRequestCryptogramError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<GenerateAuthRequestCryptogramOutput, GenerateAuthRequestCryptogramError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn key_identifier(self, input: impl Into<String>) -> Self

The keyARN of the IMK-AC (TR31_E0_EMV_MKEY_APP_CRYPTOGRAMS) that Amazon Web Services Payment Cryptography uses to generate the ARQC.

pub fn set_key_identifier(self, input: Option<String>) -> Self

The keyARN of the IMK-AC (TR31_E0_EMV_MKEY_APP_CRYPTOGRAMS) that Amazon Web Services Payment Cryptography uses to generate the ARQC.

pub fn get_key_identifier(&self) -> &Option<String>

The keyARN of the IMK-AC (TR31_E0_EMV_MKEY_APP_CRYPTOGRAMS) that Amazon Web Services Payment Cryptography uses to generate the ARQC.

pub fn transaction_data(self, input: impl Into<String>) -> Self

The transaction data that Amazon Web Services Payment Cryptography uses for ARQC generation. The same transaction data is used for ARQC verification by the issuer using VerifyAuthRequestCryptogram.

pub fn set_transaction_data(self, input: Option<String>) -> Self

The transaction data that Amazon Web Services Payment Cryptography uses for ARQC generation. The same transaction data is used for ARQC verification by the issuer using VerifyAuthRequestCryptogram.

pub fn get_transaction_data(&self) -> &Option<String>

The transaction data that Amazon Web Services Payment Cryptography uses for ARQC generation. The same transaction data is used for ARQC verification by the issuer using VerifyAuthRequestCryptogram.

pub fn major_key_derivation_mode(self, input: MajorKeyDerivationMode) -> Self

The method to use when deriving the major encryption key for ARQC generation within Amazon Web Services Payment Cryptography.

pub fn set_major_key_derivation_mode( self, input: Option<MajorKeyDerivationMode>, ) -> Self

The method to use when deriving the major encryption key for ARQC generation within Amazon Web Services Payment Cryptography.

pub fn get_major_key_derivation_mode(&self) -> &Option<MajorKeyDerivationMode>

The method to use when deriving the major encryption key for ARQC generation within Amazon Web Services Payment Cryptography.

pub fn session_key_derivation_attributes( self, input: SessionKeyDerivation, ) -> Self

The attributes and values to use for deriving a session key for ARQC generation within Amazon Web Services Payment Cryptography.

pub fn set_session_key_derivation_attributes( self, input: Option<SessionKeyDerivation>, ) -> Self

The attributes and values to use for deriving a session key for ARQC generation within Amazon Web Services Payment Cryptography.

pub fn get_session_key_derivation_attributes( &self, ) -> &Option<SessionKeyDerivation>

The attributes and values to use for deriving a session key for ARQC generation within Amazon Web Services Payment Cryptography.